@@ -22,7 +22,7 @@ import typing
 import paho.mqtt.client
 
 from switchbot_mqtt._actors import _ButtonAutomator, _CurtainMotor
-from switchbot_mqtt._actors._base import _MQTTCallbackUserdata
+from switchbot_mqtt._actors.base import _MQTTCallbackUserdata
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -38,23 +38,18 @@ def _mqtt_on_connect(
     assert return_code == 0, return_code  # connection accepted
     mqtt_broker_host, mqtt_broker_port = mqtt_client.socket().getpeername()
     _LOGGER.debug("connected to MQTT broker %s:%d", mqtt_broker_host, mqtt_broker_port)
-    _ButtonAutomator.mqtt_subscribe(
-        mqtt_client=mqtt_client,
-        enable_device_info_update_topic=userdata.fetch_device_info,
-    )
-    _CurtainMotor.mqtt_subscribe(
-        mqtt_client=mqtt_client,
-        enable_device_info_update_topic=userdata.fetch_device_info,
-    )
+    _ButtonAutomator.mqtt_subscribe(mqtt_client=mqtt_client, settings=userdata)
+    _CurtainMotor.mqtt_subscribe(mqtt_client=mqtt_client, settings=userdata)
 
 
 def _run(
     *,
     mqtt_host: str,
     mqtt_port: int,
+    mqtt_disable_tls: bool,
     mqtt_username: typing.Optional[str],
     mqtt_password: typing.Optional[str],
-    mqtt_disable_tls: bool,
+    mqtt_topic_prefix: str,
     retry_count: int,
     device_passwords: typing.Dict[str, str],
     fetch_device_info: bool,
@@ -65,6 +60,7 @@ def _run(
             retry_count=retry_count,
             device_passwords=device_passwords,
             fetch_device_info=fetch_device_info,
+            mqtt_topic_prefix=mqtt_topic_prefix,
         )
     )
     mqtt_client.on_connect = _mqtt_on_connect
