@@ -22,7 +22,7 @@ import paho.mqtt.client
 import pytest
 import switchbot
 
-import switchbot_mqtt._actors._base
+import switchbot_mqtt._actors.base
 
 # pylint: disable=protected-access
 
@@ -30,13 +30,13 @@ import switchbot_mqtt._actors._base
 def test_abstract() -> None:
     with pytest.raises(TypeError, match=r"\babstract class\b"):
         # pylint: disable=abstract-class-instantiated
-        switchbot_mqtt._actors._base._MQTTControlledActor(  # type: ignore
+        switchbot_mqtt._actors.base._MQTTControlledActor(  # type: ignore
             mac_address="dummy", retry_count=21, password=None
         )
 
 
 def test_execute_command_abstract() -> None:
-    class _ActorMock(switchbot_mqtt._actors._base._MQTTControlledActor):
+    class _ActorMock(switchbot_mqtt._actors.base._MQTTControlledActor):
         def __init__(
             self, mac_address: str, retry_count: int, password: typing.Optional[str]
         ) -> None:
@@ -46,14 +46,18 @@ def test_execute_command_abstract() -> None:
 
         def execute_command(
             self,
+            *,
             mqtt_message_payload: bytes,
             mqtt_client: paho.mqtt.client.Client,
             update_device_info: bool,
+            mqtt_topic_prefix: str,
         ) -> None:
+            assert 21
             super().execute_command(
                 mqtt_message_payload=mqtt_message_payload,
                 mqtt_client=mqtt_client,
                 update_device_info=update_device_info,
+                mqtt_topic_prefix=mqtt_topic_prefix,
             )
 
         def _get_device(self) -> switchbot.SwitchbotDevice:
@@ -63,7 +67,10 @@ def test_execute_command_abstract() -> None:
     actor = _ActorMock(mac_address="aa:bb:cc:dd:ee:ff", retry_count=42, password=None)
     with pytest.raises(NotImplementedError):
         actor.execute_command(
-            mqtt_message_payload=b"dummy", mqtt_client="dummy", update_device_info=True
+            mqtt_message_payload=b"dummy",
+            mqtt_client="dummy",
+            update_device_info=True,
+            mqtt_topic_prefix="whatever",
         )
     with pytest.raises(NotImplementedError):
         actor._get_device()
