@@ -27,7 +27,7 @@ from paho.mqtt.client import MQTT_ERR_QUEUE_SIZE, MQTT_ERR_SUCCESS, MQTTMessage,
 import switchbot_mqtt
 import switchbot_mqtt._actors
 from switchbot_mqtt._actors import _ButtonAutomator, _CurtainMotor
-from switchbot_mqtt._actors._base import _MQTTCallbackUserdata, _MQTTControlledActor
+from switchbot_mqtt._actors.base import _MQTTCallbackUserdata, _MQTTControlledActor
 from switchbot_mqtt._utils import _MQTTTopicLevel, _MQTTTopicPlaceholder
 
 # pylint: disable=protected-access
@@ -56,9 +56,10 @@ def test__run(
         switchbot_mqtt._run(
             mqtt_host=mqtt_host,
             mqtt_port=mqtt_port,
+            mqtt_disable_tls=False,
             mqtt_username=None,
             mqtt_password=None,
-            mqtt_disable_tls=False,
+            mqtt_topic_prefix="homeassistant/",
             retry_count=retry_count,
             device_passwords=device_passwords,
             fetch_device_info=fetch_device_info,
@@ -71,6 +72,7 @@ def test__run(
         retry_count=retry_count,
         device_passwords=device_passwords,
         fetch_device_info=fetch_device_info,
+        mqtt_topic_prefix="homeassistant/",
     )
     assert not mqtt_client_mock().username_pw_set.called
     mqtt_client_mock().tls_set.assert_called_once_with(ca_certs=None)
@@ -116,12 +118,12 @@ def test__run(
     ]
     assert len(caplog.record_tuples) == (7 if fetch_device_info else 5)
     assert (
-        "switchbot_mqtt._actors._base",
+        "switchbot_mqtt._actors.base",
         logging.INFO,
         "subscribing to MQTT topic 'homeassistant/switch/switchbot/+/set'",
     ) in caplog.record_tuples
     assert (
-        "switchbot_mqtt._actors._base",
+        "switchbot_mqtt._actors.base",
         logging.INFO,
         "subscribing to MQTT topic 'homeassistant/cover/switchbot-curtain/+/set'",
     ) in caplog.record_tuples
@@ -137,9 +139,10 @@ def test__run_tls(
         switchbot_mqtt._run(
             mqtt_host="mqtt.local",
             mqtt_port=1234,
+            mqtt_disable_tls=mqtt_disable_tls,
             mqtt_username=None,
             mqtt_password=None,
-            mqtt_disable_tls=mqtt_disable_tls,
+            mqtt_topic_prefix="prfx",
             retry_count=21,
             device_passwords={},
             fetch_device_info=True,
@@ -168,16 +171,20 @@ def test__run_authentication(
         switchbot_mqtt._run(
             mqtt_host=mqtt_host,
             mqtt_port=mqtt_port,
+            mqtt_disable_tls=True,
             mqtt_username=mqtt_username,
             mqtt_password=mqtt_password,
-            mqtt_disable_tls=True,
+            mqtt_topic_prefix="prfx",
             retry_count=7,
             device_passwords={},
             fetch_device_info=True,
         )
     mqtt_client_mock.assert_called_once_with(
         userdata=_MQTTCallbackUserdata(
-            retry_count=7, device_passwords={}, fetch_device_info=True
+            retry_count=7,
+            device_passwords={},
+            fetch_device_info=True,
+            mqtt_topic_prefix="prfx",
         )
     )
     mqtt_client_mock().username_pw_set.assert_called_once_with(
@@ -196,9 +203,10 @@ def test__run_authentication_missing_username(
             switchbot_mqtt._run(
                 mqtt_host=mqtt_host,
                 mqtt_port=mqtt_port,
+                mqtt_disable_tls=True,
                 mqtt_username=None,
                 mqtt_password=mqtt_password,
-                mqtt_disable_tls=True,
+                mqtt_topic_prefix="whatever",
                 retry_count=3,
                 device_passwords={},
                 fetch_device_info=True,
@@ -223,9 +231,11 @@ def _mock_actor_class(
 
         def execute_command(
             self,
+            *,
             mqtt_message_payload: bytes,
             mqtt_client: Client,
             update_device_info: bool,
+            mqtt_topic_prefix: str,
         ) -> None:
             pass
 
@@ -240,7 +250,7 @@ def _mock_actor_class(
     [
         (
             switchbot_mqtt._actors._ButtonAutomator._MQTT_UPDATE_DEVICE_INFO_TOPIC_LEVELS,
-            b"homeassistant/switch/switchbot/aa:bb:cc:dd:ee:ff/request-device-info",
+            b"prfx/switch/switchbot/aa:bb:cc:dd:ee:ff/request-device-info",
             "aa:bb:cc:dd:ee:ff",
         ),
     ],
@@ -260,6 +270,7 @@ def test__mqtt_update_device_info_callback(
         retry_count=21,  # tested in test__mqtt_command_callback
         device_passwords={},
         fetch_device_info=True,
+        mqtt_topic_prefix="prfx/",
     )
     with unittest.mock.patch.object(
         ActorMock, "__init__", return_value=None
@@ -274,10 +285,12 @@ def test__mqtt_update_device_info_callback(
     init_mock.assert_called_once_with(
         mac_address=expected_mac_address, retry_count=21, password=None
     )
-    update_mock.assert_called_once_with("client_dummy")
+    update_mock.assert_called_once_with(
+        mqtt_client="client_dummy", mqtt_topic_prefix="prfx/"
+    )
     assert caplog.record_tuples == [
         (
-            "switchbot_mqtt._actors._base",
+            "switchbot_mqtt._actors.base",
             logging.DEBUG,
             f"received topic={topic.decode()} payload={payload!r}",
         )
@@ -303,7 +316,10 @@ def test__mqtt_update_device_info_callback_ignore_retained(
         ActorMock._mqtt_update_device_info_callback(
             "client_dummy",
             _MQTTCallbackUserdata(
-                retry_count=21, device_passwords={}, fetch_device_info=True
+                retry_count=21,
+                device_passwords={},
+                fetch_device_info=True,
+                mqtt_topic_prefix="ignored",
             ),
             message,
         )
@@ -311,54 +327,67 @@ def test__mqtt_update_device_info_callback_ignore_retained(
     execute_command_mock.assert_not_called()
     assert caplog.record_tuples == [
         (
-            "switchbot_mqtt._actors._base",
+            "switchbot_mqtt._actors.base",
             logging.DEBUG,
             "received topic=aa:bb:cc:dd:ee:ff/request payload=b''",
         ),
-        ("switchbot_mqtt._actors._base", logging.INFO, "ignoring retained message"),
+        ("switchbot_mqtt._actors.base", logging.INFO, "ignoring retained message"),
     ]
 
 
 @pytest.mark.parametrize(
-    ("command_topic_levels", "topic", "payload", "expected_mac_address"),
+    (
+        "topic_prefix",
+        "command_topic_levels",
+        "topic",
+        "payload",
+        "expected_mac_address",
+    ),
     [
         (
+            "homeassistant/",
             _ButtonAutomator.MQTT_COMMAND_TOPIC_LEVELS,
             b"homeassistant/switch/switchbot/aa:bb:cc:dd:ee:ff/set",
             b"ON",
             "aa:bb:cc:dd:ee:ff",
         ),
         (
+            "homeassistant/",
             _ButtonAutomator.MQTT_COMMAND_TOPIC_LEVELS,
             b"homeassistant/switch/switchbot/aa:bb:cc:dd:ee:ff/set",
             b"OFF",
             "aa:bb:cc:dd:ee:ff",
         ),
         (
+            "homeassistant/",
             _ButtonAutomator.MQTT_COMMAND_TOPIC_LEVELS,
             b"homeassistant/switch/switchbot/aa:bb:cc:dd:ee:ff/set",
             b"on",
             "aa:bb:cc:dd:ee:ff",
         ),
         (
+            "homeassistant/",
             _ButtonAutomator.MQTT_COMMAND_TOPIC_LEVELS,
             b"homeassistant/switch/switchbot/aa:bb:cc:dd:ee:ff/set",
             b"off",
             "aa:bb:cc:dd:ee:ff",
         ),
         (
+            "prefix-",
             _ButtonAutomator.MQTT_COMMAND_TOPIC_LEVELS,
-            b"homeassistant/switch/switchbot/aa:01:23:45:67:89/set",
+            b"prefix-switch/switchbot/aa:01:23:45:67:89/set",
             b"ON",
             "aa:01:23:45:67:89",
         ),
         (
+            "",
             ["switchbot", _MQTTTopicPlaceholder.MAC_ADDRESS],
             b"switchbot/aa:01:23:45:67:89",
             b"ON",
             "aa:01:23:45:67:89",
         ),
         (
+            "homeassistant/",
             _CurtainMotor.MQTT_COMMAND_TOPIC_LEVELS,
             b"homeassistant/cover/switchbot-curtain/aa:01:23:45:67:89/set",
             b"OPEN",
@@ -370,6 +399,7 @@ def test__mqtt_update_device_info_callback_ignore_retained(
 @pytest.mark.parametrize("fetch_device_info", [True, False])
 def test__mqtt_command_callback(
     caplog: _pytest.logging.LogCaptureFixture,
+    topic_prefix: str,
     command_topic_levels: typing.Tuple[_MQTTTopicLevel, ...],
     topic: bytes,
     payload: bytes,
@@ -384,6 +414,7 @@ def test__mqtt_command_callback(
         retry_count=retry_count,
         device_passwords={},
         fetch_device_info=fetch_device_info,
+        mqtt_topic_prefix=topic_prefix,
     )
     with unittest.mock.patch.object(
         ActorMock, "__init__", return_value=None
@@ -400,10 +431,11 @@ def test__mqtt_command_callback(
         mqtt_client="client_dummy",
         mqtt_message_payload=payload,
         update_device_info=fetch_device_info,
+        mqtt_topic_prefix=topic_prefix,
     )
     assert caplog.record_tuples == [
         (
-            "switchbot_mqtt._actors._base",
+            "switchbot_mqtt._actors.base",
             logging.DEBUG,
             f"received topic={topic.decode()} payload={payload!r}",
         )
@@ -424,7 +456,7 @@ def test__mqtt_command_callback_password(
     ActorMock = _mock_actor_class(
         command_topic_levels=("switchbot", _MQTTTopicPlaceholder.MAC_ADDRESS)
     )
-    message = MQTTMessage(topic=b"switchbot/" + mac_address.encode())
+    message = MQTTMessage(topic=b"prefix-switchbot/" + mac_address.encode())
     message.payload = b"whatever"
     callback_userdata = _MQTTCallbackUserdata(
         retry_count=3,
@@ -434,6 +466,7 @@ def test__mqtt_command_callback_password(
             "11:22:33:dd:ee:ff": "äöü",
         },
         fetch_device_info=True,
+        mqtt_topic_prefix="prefix-",
     )
     with unittest.mock.patch.object(
         ActorMock, "__init__", return_value=None
@@ -448,6 +481,7 @@ def test__mqtt_command_callback_password(
         mqtt_client="client_dummy",
         mqtt_message_payload=b"whatever",
         update_device_info=True,
+        mqtt_topic_prefix="prefix-",
     )
 
 
@@ -477,7 +511,10 @@ def test__mqtt_command_callback_unexpected_topic(
         ActorMock._mqtt_command_callback(
             "client_dummy",
             _MQTTCallbackUserdata(
-                retry_count=3, device_passwords={}, fetch_device_info=True
+                retry_count=3,
+                device_passwords={},
+                fetch_device_info=True,
+                mqtt_topic_prefix="homeassistant/",
             ),
             message,
         )
@@ -485,12 +522,12 @@ def test__mqtt_command_callback_unexpected_topic(
     execute_command_mock.assert_not_called()
     assert caplog.record_tuples == [
         (
-            "switchbot_mqtt._actors._base",
+            "switchbot_mqtt._actors.base",
             logging.DEBUG,
             f"received topic={topic.decode()} payload={payload!r}",
         ),
         (
-            "switchbot_mqtt._actors._base",
+            "switchbot_mqtt._actors.base",
             logging.WARNING,
             f"unexpected topic {topic.decode()}",
         ),
@@ -504,7 +541,7 @@ def test__mqtt_command_callback_invalid_mac_address(
     ActorMock = _mock_actor_class(
         command_topic_levels=_ButtonAutomator.MQTT_COMMAND_TOPIC_LEVELS
     )
-    topic = f"homeassistant/switch/switchbot/{mac_address}/set".encode()
+    topic = f"mqttprefix-switch/switchbot/{mac_address}/set".encode()
     message = MQTTMessage(topic=topic)
     message.payload = payload
     with unittest.mock.patch.object(
@@ -517,7 +554,10 @@ def test__mqtt_command_callback_invalid_mac_address(
         ActorMock._mqtt_command_callback(
             "client_dummy",
             _MQTTCallbackUserdata(
-                retry_count=3, device_passwords={}, fetch_device_info=True
+                retry_count=3,
+                device_passwords={},
+                fetch_device_info=True,
+                mqtt_topic_prefix="mqttprefix-",
             ),
             message,
         )
@@ -525,12 +565,12 @@ def test__mqtt_command_callback_invalid_mac_address(
     execute_command_mock.assert_not_called()
     assert caplog.record_tuples == [
         (
-            "switchbot_mqtt._actors._base",
+            "switchbot_mqtt._actors.base",
             logging.DEBUG,
             f"received topic={topic.decode()} payload={payload!r}",
         ),
         (
-            "switchbot_mqtt._actors._base",
+            "switchbot_mqtt._actors.base",
             logging.WARNING,
             f"invalid mac address {mac_address}",
         ),
@@ -560,7 +600,10 @@ def test__mqtt_command_callback_ignore_retained(
         ActorMock._mqtt_command_callback(
             "client_dummy",
             _MQTTCallbackUserdata(
-                retry_count=4, device_passwords={}, fetch_device_info=True
+                retry_count=4,
+                device_passwords={},
+                fetch_device_info=True,
+                mqtt_topic_prefix="homeassistant/",
             ),
             message,
         )
@@ -568,24 +611,26 @@ def test__mqtt_command_callback_ignore_retained(
     execute_command_mock.assert_not_called()
     assert caplog.record_tuples == [
         (
-            "switchbot_mqtt._actors._base",
+            "switchbot_mqtt._actors.base",
             logging.DEBUG,
             f"received topic={topic.decode()} payload={payload!r}",
         ),
-        ("switchbot_mqtt._actors._base", logging.INFO, "ignoring retained message"),
+        ("switchbot_mqtt._actors.base", logging.INFO, "ignoring retained message"),
     ]
 
 
 @pytest.mark.parametrize(
-    ("state_topic_levels", "mac_address", "expected_topic"),
+    ("topic_prefix", "state_topic_levels", "mac_address", "expected_topic"),
     # https://www.home-assistant.io/docs/mqtt/discovery/#switches
     [
         (
+            "homeassistant/",
             _ButtonAutomator.MQTT_STATE_TOPIC_LEVELS,
             "aa:bb:cc:dd:ee:ff",
             "homeassistant/switch/switchbot/aa:bb:cc:dd:ee:ff/state",
         ),
         (
+            "",
             ["switchbot", _MQTTTopicPlaceholder.MAC_ADDRESS, "state"],
             "aa:bb:cc:dd:ee:gg",
             "switchbot/aa:bb:cc:dd:ee:gg/state",
@@ -596,6 +641,7 @@ def test__mqtt_command_callback_ignore_retained(
 @pytest.mark.parametrize("return_code", [MQTT_ERR_SUCCESS, MQTT_ERR_QUEUE_SIZE])
 def test__report_state(
     caplog: _pytest.logging.LogCaptureFixture,
+    topic_prefix: str,
     state_topic_levels: typing.Tuple[_MQTTTopicLevel, ...],
     mac_address: str,
     expected_topic: str,
@@ -615,9 +661,11 @@ def test__report_state(
 
         def execute_command(
             self,
+            *,
             mqtt_message_payload: bytes,
             mqtt_client: Client,
             update_device_info: bool,
+            mqtt_topic_prefix: str,
         ) -> None:
             pass
 
@@ -628,12 +676,16 @@ def test__report_state(
     mqtt_client_mock.publish.return_value.rc = return_code
     with caplog.at_level(logging.DEBUG):
         actor = _ActorMock(mac_address=mac_address, retry_count=3, password=None)
-        actor.report_state(state=state, mqtt_client=mqtt_client_mock)
+        actor.report_state(
+            state=state,
+            mqtt_client=mqtt_client_mock,
+            mqtt_topic_prefix=topic_prefix,
+        )
     mqtt_client_mock.publish.assert_called_once_with(
         topic=expected_topic, payload=state, retain=True
     )
     assert caplog.record_tuples[0] == (
-        "switchbot_mqtt._actors._base",
+        "switchbot_mqtt._actors.base",
         logging.DEBUG,
         f"publishing topic={expected_topic} payload={state!r}",
     )
@@ -642,7 +694,7 @@ def test__report_state(
     else:
         assert caplog.record_tuples[1:] == [
             (
-                "switchbot_mqtt._actors._base",
+                "switchbot_mqtt._actors.base",
                 logging.ERROR,
                 f"Failed to publish MQTT message on topic {expected_topic} (rc={return_code})",
             )
